=======
tsfresh
=======

This is the documentation of **tsfresh**.

tsfresh is a python package.
It automatically calculates a large number of time series characteristics, the so called features.
Further the package contains methods to evaluate the explaining power and importance of such characteristics for
regression or classification tasks.

You can jump right into the package by looking into our :ref:`quick-start-label`.

Contents
========

The following chapters will explain the tsfresh package in detail:

.. toctree::
   :maxdepth: 1

   Introduction <text/introduction>
   Quick Start <text/quick_start>
   Module Reference <api/modules>
   Data Formats <text/data_formats>
   scikit-learn Transformers <text/sklearn_transformers>
   List of Calculated Features <text/list_of_features>
   Feature Calculation <text/feature_calculation>
   Feature Calculator Settings <text/feature_extraction_settings>
   Feature Filtering <text/feature_filtering>
   How to write custom Feature Calculators <text/how_to_add_custom_feature>
   Parallelization <text/parallelization>
   Time Series Forecasting <text/forecasting>
   FAQ <text/faq>
   Authors <authors>
   License <license>
   Changelog <changes>
   How to contribute <text/how_to_contribute>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Acknowledgements
================

The research and development of TSFRESH was funded in part by the German Federal Ministry of Education and Research
under grant number 01IS14004 (project iPRODICT).
